<?php

namespace Drupal\confection\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Provides a 'ConfectionBlock' block.
 *
 * @Block(
 *  id = "confection_block",
 *  admin_label = @Translation("Confection"),
 * )
 */
class ConfectionBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * GuzzleHttp\ClientInterface definition.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;




  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->httpClient = $container->get('http_client');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
    ] + parent::defaultConfiguration();
  }



  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('confection.confection');



    //Translate strings
    $confection_strings = array(
      'banner_none' => t('This site isn’t collecting your personal information. Any information you submitted before opting out is still in our system. To manage this information, please ')->__toString(),
      'banner_base' => t('The authors of this site care about your personal data. That’s why they use Confection. Our privacy-first data management app helps people like you take control of the information you share online.')->__toString(),
      'banner_strict_base' => t('At the moment, this site would like permission to use basic data to improve the content it offers you. This would include information like your IP address. We won’t collect more sensitive information such as your name or email address without asking you first.')->__toString(),
      'banner_collecting' => t('You’ve given this site permission to collect information like your IP address, name, and email.')->__toString(),
      'banner_collecting_basic' => t('Collecting Basic Data')->__toString(),
      'banner_collecting_full' => t('Fully Authorized')->__toString(),
      'banner_collecting_not' => t('Not Collecting Your Data')->__toString(),
      'banner_strict' => t('Hi, it’s Confection again. We noticed that you’re about to share information like your name and email with this site. Do we have your permission to do so?')->__toString(),
      'button_more' => t('Learn More')->__toString(),
      'button_accept' => t('Accept')->__toString(),
      'button_deny' => t('Not now')->__toString(),
      'button_stop' => t('Stop Collecting')->__toString(),
      'button_resume' => t('Resume Data Sharing')->__toString(),
      'button_close' => t('Close')->__toString(),
      'button_click' => t('click here')->__toString(),
    );


    $build = [];
    $build['#theme'] = 'confection_block';

    $items=array();
    $items['account_id'] =$config->get('account_id');
    $items['privacy_approach'] =$config->get('privacy_approach');
    $items['position'] =$config->get('position');
    $items['confection_url'] =$config->get('confection_url');
    $items['analytics'] =$config->get('analytics');
    $items['tstring'] = $confection_strings;
    $build['#content']=$items;




    return $build;
  }

}

